LIST_TYPE = {
    'db_mysql_source' : {
        'string' : 'Varchar',
        'integer' : 'Int',
        'text' : 'Text',
    },
    'db_sqlite_source' : {
        'string' : 'Text',
        'integer' : 'Integer'
    }
}